@@ -220,6 +220,26 @@ class CoordinatesDisplacement(object):
         """
         return CoordinatesDisplacement(xyz=XYZ(x, y, z))
 
+    @staticmethod
+    def from_positions(from_position: Coordinates, to_positions: Coordinates) -> 'CoordinatesDisplacement':
+        """
+        Compute the displacement vector between two positions
+
+        >>> from_position = Coordinates(0, 0, 0.1)
+        >>> to_position = Coordinates(0, 0, 0)
+        >>> c = CoordinatesDisplacement.from_positions(from_position, to_position)
+        >>> c.is_valid()
+        True
+        >>> abs(c)
+        0.1
+        """
+
+        from_xyz = from_position.xyz()
+        to_xyz = to_positions.xyz()
+        dxyz = XYZ(to_xyz.x - from_xyz.x, to_xyz.y - from_xyz.y, to_xyz.z - from_xyz.z)
+
+        return CoordinatesDisplacement(xyz=dxyz)
+
     @staticmethod
     def from_enu(e: float, n: float, u: float):
         """
@@ -231,6 +251,7 @@ class CoordinatesDisplacement(object):
 
 # ------------------------------------------------------------------------------
 
+
 def valid_coordinates(lla=None, xyz=None):
     """
     Check wether the input geographic coordinates are valid or not (in terms
